@@ -4,6 +4,6 @@ void NatFork::checkSyslogParam(char const *label,
                                string const &actual, string const &err)
 {
     if (err.length())
-        d_stdMsg << "[Warning] Using Syslog " << label << '`' <<
+        d_stdMsg << "[Warning] using syslog " << label << '`' <<
                 actual << "', ignoring unsupported " << label << '`' << endl;
 }
