@@ -1,42 +1,44 @@
 #ifndef INCLUDED_NATFORK_
 #define INCLUDED_NATFORK_
 
-#include <ostream>
+#include <fstream>
 #include <memory>
 
 #include <bobcat/fork>
 #include <bobcat/multistreambuf>
 
+#include "../options/options.h"
+#include "../rotatingstream/rotatingstream.h"
+
 namespace FBB
 {
     class SyslogStream;
 }
 
-class Options;
+class Producer;
+class Storage;
 
 class NatFork: public FBB::Fork
 {
-    enum Mode                       // working mode: use conntrack or pcap
-    {
-        ERROR,
-        CONNTRACK,
-        PCAP
-    };
-
     Options &d_options;
 
     std::unique_ptr<FBB::SyslogStream> d_syslog;
+    RotatingStream d_log;
 
     FBB::MultiStreambuf d_multiStreambuf;
     std::ostream d_stdMsg;
 
-    Mode d_mode;
+    Options::Mode d_mode;
+
+    static Producer *(*s_producer[]) (std::ostream &stdMsg, Storage &storage);
 
     public:
-        NatFork();
-
-        void run();
+        NatFork();                  // configure and initialize data
+        ~NatFork() override;
 
+        void run();                 // dameonize when running in the
+                                    // background, otherwise call
+                                    // 'childProcess'
     private:
         void specifications();
 
@@ -51,6 +53,9 @@ class NatFork: public FBB::Fork
 
         void parentProcess() override;
         void childProcess() override;
+
+        void cleanupPidFile() const;
+
 };
         
 #endif
